megicparc
=========
Python library for dividing the cortical surface based on an unsupervised 
clustering of the MEG lead fields.

Author 
------
Sara Sommariva (sommariva@dima.unige.it)

Citation
--------

If you use megicparc in your project, please consider citing our work:

.. [1] S. Sommariva1, N. Puthanmadam Subramaniyam, and L. Parkkonen. An unsupervised clustering approach for MEG
lead-field-based cortical parcellation. Submitted

